[![PyPI version](https://badge.fury.io/py/dracor.svg)](https://badge.fury.io/py/dracor)

# A simple Python library for DraCor

This project provides a simple Python library to access the
[DraCor](https://dracor.org/) [API](https://dracor.org/doc/api).

## Installation

``` shell
pip install dracor
```

## Usage

``` python
import dracor

dracor.plays("shake")
```
